import { Component, inject } from '@angular/core';
import { TranslatorService } from 'src/services/translator/translator.service';

@Component({
  selector: 'app-journal-spellbook',
  templateUrl: './journal-spellbook.component.html',
  styleUrls: ['./journal-spellbook.component.scss'],
})
export class JournalSpellbookComponent {
  public filterArtificer = false;
  public filterBard = false;
  public filterCleric = false;
  private filterDruid = false;
  private filterPaladin = false;
  private filterRanger = false;
  private filterSorcerer = false;
  private filterWarlock = false;
  private filterWizard = false;

  public translator = inject(TranslatorService);

  // public classNames = [
  //   'artificer',
  //   'bard',
  //   'cleric',
  //   'druid',
  //   'paladin',
  //   'ranger',
  //   'sorcerer',
  //   'warlock',
  //   'wizard',
  // ];

  /**
   * Toggles the selection of a given class icon. It also updates the filtered spells.
   * @param className The provided class which icon will be toggled.
   */
  public toggleClassSelection(className: string) {
    const element = document.getElementById(className);
    element!.classList.toggle('icon-active');
    this.toggleClassFilter(className);
    this.refreshFilteredSpells();
  }

  private refreshFilteredSpells() {
    console.log('Refresh filtered spells');
    console.log('Artificer: ' + this.filterArtificer);

    // console.log('Bard: ' + this.filterBard);
    console.log('Cleric: ' + this.filterCleric);
    // console.log('Druid: ' + this.filterDruid);
  }

  // Utils

  /**
   * Toggles if a given class is used to filter the spells.
   * @param className The class which icon will be toggled.
   */
  private toggleClassFilter(className: string) {
    const isActive: boolean = this.getClassFilter(className);
    this.setClassFilter(className, !isActive);
  }

  /**
   * Allows to access the corresponding varibale to a classname
   * @param className The class which varibale is looked for.
   * @returns Returns the given class filter variable.
   */
  private getClassFilter(className: string): boolean {
    switch (className) {
      case 'artificer':
        return this.filterArtificer;
      case 'bard':
        return this.filterBard;
      case 'cleric':
        return this.filterCleric;
      case 'druid':
        return this.filterDruid;
      case 'paladin':
        return this.filterPaladin;
      case 'ranger':
        return this.filterRanger;
      case 'sorcerer':
        return this.filterSorcerer;
      case 'warlock':
        return this.filterWarlock;
      case 'wizard':
        return this.filterWizard;
      default:
        return false;
    }
  }

  /**
   * Sets a value to the corresponding variable to a classname.
   * Active classes will be used to filter the spells.
   * @param className The class which variable is looked for.
   * @param value The value to be set.
   */
  private setClassFilter(className: string, value: boolean) {
    switch (className) {
      case 'artificer':
        this.filterArtificer = value;
        break;
      case 'bard':
        this.filterBard = value;
        break;
      case 'cleric':
        this.filterCleric = value;
        break;
      case 'druid':
        this.filterDruid = value;
        break;
      case 'paladin':
        this.filterPaladin = value;
        break;
      case 'ranger':
        this.filterRanger = value;
        break;
      case 'sorcerer':
        this.filterSorcerer = value;
        break;
      case 'warlock':
        this.filterWarlock = value;
        break;
      case 'wizard':
        this.filterWizard = value;
        break;
    }
  }
}
